@@ -8,16 +8,31 @@
 #![allow(non_snake_case)]
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
 
-#[macro_use]
 #[cfg(feature = "fam-wrappers")]
+#[macro_use]
 extern crate vmm_sys_util;
 
+#[cfg(feature = "serde")]
+extern crate serde;
+
+#[cfg(feature = "serde")]
+extern crate zerocopy;
+
+#[cfg(feature = "serde")]
+#[macro_use]
+mod serialize;
+
 #[cfg(target_arch = "x86_64")]
 mod x86_64;
 #[cfg(target_arch = "x86_64")]
 pub use self::x86_64::*;
 
-#[cfg(any(target_arch = "aarch", target_arch = "aarch64"))]
+#[cfg(any(target_arch = "arm", target_arch = "aarch64"))]
 mod arm64;
-#[cfg(any(target_arch = "aarch", target_arch = "aarch64"))]
+#[cfg(any(target_arch = "arm", target_arch = "aarch64"))]
 pub use self::arm64::*;
+
+#[cfg(target_arch = "riscv64")]
+mod riscv64;
+#[cfg(target_arch = "riscv64")]
+pub use self::riscv64::*;
